Mappers
=======

.. automodule:: pymbolic.mapper

More specialized mappers
------------------------

Converting to strings and code
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pymbolic.mapper.stringifier

.. automodule:: pymbolic.mapper.c_code

.. automodule:: pymbolic.mapper.graphviz

Some minimal mathematics
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pymbolic.mapper.evaluator

.. automodule:: pymbolic.mapper.differentiator

.. automodule:: pymbolic.mapper.distributor

.. automodule:: pymbolic.mapper.collector

.. automodule:: pymbolic.mapper.constant_folder
.. automodule:: pymbolic.mapper.substitutor

Finding expression properties
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pymbolic.mapper.dependency

.. automodule:: pymbolic.mapper.flop_counter

.. autoclass:: FlopCounter
.. autoclass:: CSEAwareFlopCounter

Analysis tools
^^^^^^^^^^^^^^

.. automodule:: pymbolic.mapper.analysis

Simplification
^^^^^^^^^^^^^^

.. automodule:: pymbolic.mapper.flattener


.. vim: sw=4
